@@ -44,39 +44,39 @@ using namespace Konsole;
 // gamma correction for the dim colors to compensate for bright X screens.
 // It contains the 8 ansiterm/xterm colors in 2 intensities.
 const ColorEntry ColorScheme::defaultTable[TABLE_COLORS] = {
-    ColorEntry(QColor(0x00, 0x00, 0x00)), // Dfore
-    ColorEntry(QColor(0xFF, 0xFF, 0xFF)), // Dback
-    ColorEntry(QColor(0x00, 0x00, 0x00)), // Black
-    ColorEntry(QColor(0xB2, 0x18, 0x18)), // Red
-    ColorEntry(QColor(0x18, 0xB2, 0x18)), // Green
-    ColorEntry(QColor(0xB2, 0x68, 0x18)), // Yellow
-    ColorEntry(QColor(0x18, 0x18, 0xB2)), // Blue
-    ColorEntry(QColor(0xB2, 0x18, 0xB2)), // Magenta
-    ColorEntry(QColor(0x18, 0xB2, 0xB2)), // Cyan
-    ColorEntry(QColor(0xB2, 0xB2, 0xB2)), // White
+    ColorEntry(0x00, 0x00, 0x00), // Dfore
+    ColorEntry(0xFF, 0xFF, 0xFF), // Dback
+    ColorEntry(0x00, 0x00, 0x00), // Black
+    ColorEntry(0xB2, 0x18, 0x18), // Red
+    ColorEntry(0x18, 0xB2, 0x18), // Green
+    ColorEntry(0xB2, 0x68, 0x18), // Yellow
+    ColorEntry(0x18, 0x18, 0xB2), // Blue
+    ColorEntry(0xB2, 0x18, 0xB2), // Magenta
+    ColorEntry(0x18, 0xB2, 0xB2), // Cyan
+    ColorEntry(0xB2, 0xB2, 0xB2), // White
     // intensive versions
-    ColorEntry(QColor(0x00, 0x00, 0x00)),
-    ColorEntry(QColor(0xFF, 0xFF, 0xFF)),
-    ColorEntry(QColor(0x68, 0x68, 0x68)),
-    ColorEntry(QColor(0xFF, 0x54, 0x54)),
-    ColorEntry(QColor(0x54, 0xFF, 0x54)),
-    ColorEntry(QColor(0xFF, 0xFF, 0x54)),
-    ColorEntry(QColor(0x54, 0x54, 0xFF)),
-    ColorEntry(QColor(0xFF, 0x54, 0xFF)),
-    ColorEntry(QColor(0x54, 0xFF, 0xFF)),
-    ColorEntry(QColor(0xFF, 0xFF, 0xFF)),
+    ColorEntry(0x00, 0x00, 0x00),
+    ColorEntry(0xFF, 0xFF, 0xFF),
+    ColorEntry(0x68, 0x68, 0x68),
+    ColorEntry(0xFF, 0x54, 0x54),
+    ColorEntry(0x54, 0xFF, 0x54),
+    ColorEntry(0xFF, 0xFF, 0x54),
+    ColorEntry(0x54, 0x54, 0xFF),
+    ColorEntry(0xFF, 0x54, 0xFF),
+    ColorEntry(0x54, 0xFF, 0xFF),
+    ColorEntry(0xFF, 0xFF, 0xFF),
     // Here are faint intensities, which may not be good.
     // faint versions
-    ColorEntry(QColor(0x00, 0x00, 0x00)),
-    ColorEntry(QColor(0xFF, 0xFF, 0xFF)),
-    ColorEntry(QColor(0x00, 0x00, 0x00)),
-    ColorEntry(QColor(0x65, 0x00, 0x00)),
-    ColorEntry(QColor(0x00, 0x65, 0x00)),
-    ColorEntry(QColor(0x65, 0x5E, 0x00)),
-    ColorEntry(QColor(0x00, 0x00, 0x65)),
-    ColorEntry(QColor(0x65, 0x00, 0x65)),
-    ColorEntry(QColor(0x00, 0x65, 0x65)),
-    ColorEntry(QColor(0x65, 0x65, 0x65))
+    ColorEntry(0x00, 0x00, 0x00),
+    ColorEntry(0xFF, 0xFF, 0xFF),
+    ColorEntry(0x00, 0x00, 0x00),
+    ColorEntry(0x65, 0x00, 0x00),
+    ColorEntry(0x00, 0x65, 0x00),
+    ColorEntry(0x65, 0x5E, 0x00),
+    ColorEntry(0x00, 0x00, 0x65),
+    ColorEntry(0x65, 0x00, 0x65),
+    ColorEntry(0x00, 0x65, 0x65),
+    ColorEntry(0x65, 0x65, 0x65)
 };
 
 const char * const ColorScheme::colorNames[TABLE_COLORS] = {
@@ -161,30 +161,34 @@ QString ColorScheme::translatedColorNameForIndex(int index)
 ColorScheme::ColorScheme() :
     _description(QString()),
     _name(QString()),
-    _table(0),
-    _randomTable(0),
+    _table(nullptr),
+    _randomTable(nullptr),
     _opacity(1.0),
-    _wallpaper(0)
+    _blur(false),
+    _wallpaper(nullptr)
 {
     setWallpaper(QString());
 }
 
 ColorScheme::ColorScheme(const ColorScheme &other) :
-    _table(0),
-    _randomTable(0),
+    _description(QString()),
+    _name(QString()),
+    _table(nullptr),
+    _randomTable(nullptr),
     _opacity(other._opacity),
+    _blur(other._blur),
     _wallpaper(other._wallpaper)
 {
     setName(other.name());
     setDescription(other.description());
 
-    if (other._table != 0) {
+    if (other._table != nullptr) {
         for (int i = 0; i < TABLE_COLORS; i++) {
             setColorTableEntry(i, other._table[i]);
         }
     }
 
-    if (other._randomTable != 0) {
+    if (other._randomTable != nullptr) {
         for (int i = 0; i < TABLE_COLORS; i++) {
             const RandomizationRange &range = other._randomTable[i];
             setRandomizationRange(i, range.hue, range.saturation, range.value);
@@ -198,9 +202,9 @@ ColorScheme::~ColorScheme()
     delete[] _randomTable;
 }
 
-void ColorScheme::setDescription(const QString &aDescription)
+void ColorScheme::setDescription(const QString &description)
 {
-    _description = aDescription;
+    _description = description;
 }
 
 QString ColorScheme::description() const
@@ -208,9 +212,9 @@ QString ColorScheme::description() const
     return _description;
 }
 
-void ColorScheme::setName(const QString &aName)
+void ColorScheme::setName(const QString &name)
 {
-    _name = aName;
+    _name = name;
 }
 
 QString ColorScheme::name() const
@@ -239,7 +243,7 @@ ColorEntry ColorScheme::colorEntry(int index, uint randomSeed) const
 
     ColorEntry entry = colorTable()[index];
 
-    if (randomSeed == 0 || _randomTable == 0 || _randomTable[index].isNull()) {
+    if (randomSeed == 0 || _randomTable == nullptr || _randomTable[index].isNull()) {
         return entry;
     }
 
@@ -288,7 +292,7 @@ void ColorScheme::getColorTable(ColorEntry *table, uint randomSeed) const
 
 bool ColorScheme::randomizedBackgroundColor() const
 {
-    return _randomTable == 0 ? false : !_randomTable[BGCOLOR_INDEX].isNull();
+    return _randomTable == nullptr ? false : !_randomTable[BGCOLOR_INDEX].isNull();
 }
 
 void ColorScheme::setRandomizedBackgroundColor(bool randomize)
@@ -311,7 +315,7 @@ void ColorScheme::setRandomizationRange(int index, quint16 hue, quint8 saturatio
     Q_ASSERT(hue <= MAX_HUE);
     Q_ASSERT(index >= 0 && index < TABLE_COLORS);
 
-    if (_randomTable == 0) {
+    if (_randomTable == nullptr) {
         _randomTable = new RandomizationRange[TABLE_COLORS];
     }
 
@@ -346,9 +350,9 @@ bool ColorScheme::hasDarkBackground() const
     return backgroundColor().value() < 127;
 }
 
-void ColorScheme::setOpacity(qreal aOpacity)
+void ColorScheme::setOpacity(qreal opacity)
 {
-    _opacity = aOpacity;
+    _opacity = opacity;
 }
 
 qreal ColorScheme::opacity() const
@@ -356,6 +360,16 @@ qreal ColorScheme::opacity() const
     return _opacity;
 }
 
+void ColorScheme::setBlur(bool blur)
+{
+    _blur = blur;
+}
+
+bool ColorScheme::blur() const
+{
+    return _blur;
+}
+
 void ColorScheme::read(const KConfig &config)
 {
     KConfigGroup configGroup = config.group("General");
@@ -363,7 +377,8 @@ void ColorScheme::read(const KConfig &config)
     const QString schemeDescription = configGroup.readEntry("Description", i18nc("@item", "Un-named Color Scheme"));
 
     _description = i18n(schemeDescription.toUtf8().constData());
-    _opacity = configGroup.readEntry("Opacity", qreal(1.0));
+    _opacity = configGroup.readEntry("Opacity", 1.0);
+    _blur = configGroup.readEntry("Blur", false);
     setWallpaper(configGroup.readEntry("Wallpaper", QString()));
 
     for (int i = 0; i < TABLE_COLORS; i++) {
@@ -374,7 +389,7 @@ void ColorScheme::readColorEntry(const KConfig &config, int index)
 {
     KConfigGroup configGroup = config.group(colorNameForIndex(index));
 
-    if (!configGroup.hasKey("Color") && _table != 0) {
+    if (!configGroup.hasKey("Color") && _table != nullptr) {
         setColorTableEntry(index, _table[index%BASE_COLORS]);
         return;
     }
@@ -400,6 +415,7 @@ void ColorScheme::write(KConfig &config) const
 
     configGroup.writeEntry("Description", _description);
     configGroup.writeEntry("Opacity", _opacity);
+    configGroup.writeEntry("Blur", _blur);
     configGroup.writeEntry("Wallpaper", _wallpaper->path());
 
     for (int i = 0; i < TABLE_COLORS; i++) {
@@ -426,7 +442,7 @@ void ColorScheme::writeColorEntry(KConfig &config, int index) const
         configGroup.deleteEntry("Bold");
     }
 
-    RandomizationRange random = _randomTable != 0 ? _randomTable[index] : RandomizationRange();
+    RandomizationRange random = _randomTable != nullptr ? _randomTable[index] : RandomizationRange();
 
     // record randomization if this color has randomization or
     // if one of the keys already exists
@@ -447,9 +463,9 @@ ColorSchemeWallpaper::Ptr ColorScheme::wallpaper() const
     return _wallpaper;
 }
 
-ColorSchemeWallpaper::ColorSchemeWallpaper(const QString &aPath) :
-    _path(aPath),
-    _picture(0)
+ColorSchemeWallpaper::ColorSchemeWallpaper(const QString &path) :
+    _path(path),
+    _picture(nullptr)
 {
 }
 
@@ -479,13 +495,13 @@ bool ColorSchemeWallpaper::isNull() const
     return _path.isEmpty();
 }
 
-bool ColorSchemeWallpaper::draw(QPainter &painter, const QRect &rect, qreal opacity)
+bool ColorSchemeWallpaper::draw(QPainter &painter, const QRect rect, qreal opacity)
 {
     if ((_picture == nullptr) || _picture->isNull()) {
         return false;
     }
 
-    if (qFuzzyCompare(1.0, opacity)) {
+    if (qFuzzyCompare(qreal(1.0), opacity)) {
         painter.drawTiledPixmap(rect, *_picture, rect.topLeft());
         return true;
     }
