@@ -2,6 +2,7 @@
     This source file is part of Konsole, a terminal emulator.
 
     Copyright 2007-2008 by Robert Knight <robertknight@gmail.com>
+    Copyright 2018 by Harald Sitter <sitter@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,20 +23,22 @@
 // Own
 #include "ColorSchemeManager.h"
 
+#include "konsoledebug.h"
+
 // Qt
-#include <QtCore/QIODevice>
-#include <QtCore/QFileInfo>
-#include <QtCore/QFile>
-#include <QtCore/QDir>
+#include <QIODevice>
+#include <QFileInfo>
+#include <QFile>
+#include <QDir>
 
 // KDE
 #include <KConfig>
-#include <QDebug>
 
 using namespace Konsole;
 
-ColorSchemeManager::ColorSchemeManager()
-    : _haveLoadedAll(false)
+ColorSchemeManager::ColorSchemeManager() :
+    _colorSchemes(QHash<QString, const ColorScheme *>()),
+    _haveLoadedAll(false)
 {
 }
 
@@ -57,20 +60,22 @@ void ColorSchemeManager::loadAllColorSchemes()
     int failed = 0;
 
     QStringList nativeColorSchemes = listColorSchemes();
-    foreach(const QString& colorScheme, nativeColorSchemes) {
-        if (loadColorScheme(colorScheme))
+    foreach (const QString &colorScheme, nativeColorSchemes) {
+        if (loadColorScheme(colorScheme)) {
             success++;
-        else
+        } else {
             failed++;
+        }
     }
 
-    if (failed > 0)
-        qWarning() << "failed to load " << failed << " color schemes.";
+    if (failed > 0) {
+        qCDebug(KonsoleDebug) << "failed to load " << failed << " color schemes.";
+    }
 
     _haveLoadedAll = true;
 }
 
-QList<const ColorScheme*> ColorSchemeManager::allColorSchemes()
+QList<const ColorScheme *> ColorSchemeManager::allColorSchemes()
 {
     if (!_haveLoadedAll) {
         loadAllColorSchemes();
@@ -79,25 +84,27 @@ QList<const ColorScheme*> ColorSchemeManager::allColorSchemes()
     return _colorSchemes.values();
 }
 
-bool ColorSchemeManager::loadColorScheme(const QString& filePath)
+bool ColorSchemeManager::loadColorScheme(const QString &filePath)
 {
-    if (!filePath.endsWith(QLatin1String(".colorscheme")) || !QFile::exists(filePath))
+    if (!pathIsColorScheme(filePath) || !QFile::exists(filePath)) {
         return false;
+    }
 
-    QFileInfo info(filePath);
+    auto name = colorSchemeNameFromPath(filePath);
 
-    KConfig config(filePath , KConfig::NoGlobals);
-    ColorScheme* scheme = new ColorScheme();
-    scheme->setName(info.baseName());
+    KConfig config(filePath, KConfig::NoGlobals);
+    auto scheme = new ColorScheme();
+    scheme->setName(name);
     scheme->read(config);
 
     if (scheme->name().isEmpty()) {
-        qWarning() << "Color scheme in" << filePath << "does not have a valid name and was not loaded.";
+        qCDebug(KonsoleDebug) << "Color scheme in" << filePath
+                              << "does not have a valid name and was not loaded.";
         delete scheme;
         return false;
     }
 
-    if (!_colorSchemes.contains(info.baseName())) {
+    if (!_colorSchemes.contains(name)) {
         _colorSchemes.insert(scheme->name(), scheme);
     } else {
         //qDebug() << "color scheme with name" << scheme->name() << "has already been" <<
@@ -109,74 +116,92 @@ bool ColorSchemeManager::loadColorScheme(const QString& filePath)
     return true;
 }
 
+bool ColorSchemeManager::unloadColorScheme(const QString &filePath)
+{
+    if (!pathIsColorScheme(filePath)) {
+        return false;
+    }
+    auto name = colorSchemeNameFromPath(filePath);
+    delete _colorSchemes.take(name);
+    return true;
+}
+
+QString ColorSchemeManager::colorSchemeNameFromPath(const QString &path)
+{
+    if (!pathIsColorScheme(path)) {
+        return QString();
+    }
+    return QFileInfo(path).completeBaseName();
+}
+
 QStringList ColorSchemeManager::listColorSchemes()
 {
     QStringList colorschemes;
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konsole"), QStandardPaths::LocateDirectory);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konsole"),
+                                                       QStandardPaths::LocateDirectory);
     colorschemes.reserve(dirs.size());
 
-    Q_FOREACH (const QString& dir, dirs) {
+    Q_FOREACH (const QString &dir, dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.colorscheme"));
-        Q_FOREACH (const QString& file, fileNames) {
-            colorschemes.append(dir + '/' + file);
+        Q_FOREACH (const QString &file, fileNames) {
+            colorschemes.append(dir + QLatin1Char('/') + file);
         }
     }
     return colorschemes;
 }
 
-
 const ColorScheme ColorSchemeManager::_defaultColorScheme;
-const ColorScheme* ColorSchemeManager::defaultColorScheme() const
+const ColorScheme *ColorSchemeManager::defaultColorScheme() const
 {
     return &_defaultColorScheme;
 }
 
-void ColorSchemeManager::addColorScheme(ColorScheme* scheme)
+void ColorSchemeManager::addColorScheme(ColorScheme *scheme)
 {
     // remove existing colorscheme with the same name
     if (_colorSchemes.contains(scheme->name())) {
-        delete _colorSchemes[scheme->name()];
-        _colorSchemes.remove(scheme->name());
+        delete _colorSchemes.take(scheme->name());
     }
 
     _colorSchemes.insert(scheme->name(), scheme);
 
     // save changes to disk
 
-    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/konsole/");
+    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
+                        + QStringLiteral("/konsole/");
     QDir().mkpath(dir);
     const QString path = dir + scheme->name() + QStringLiteral(".colorscheme");
-    KConfig config(path , KConfig::NoGlobals);
+    KConfig config(path, KConfig::NoGlobals);
 
     scheme->write(config);
 }
 
-bool ColorSchemeManager::deleteColorScheme(const QString& name)
+bool ColorSchemeManager::deleteColorScheme(const QString &name)
 {
     Q_ASSERT(_colorSchemes.contains(name));
 
     // look up the path and delete
     QString path = findColorSchemePath(name);
     if (QFile::remove(path)) {
-        delete _colorSchemes[name];
-        _colorSchemes.remove(name);
+        delete _colorSchemes.take(name);
         return true;
     } else {
-        qWarning() << "Failed to remove color scheme -" << path;
+        qCDebug(KonsoleDebug)<<"Failed to remove color scheme -"<<path;
         return false;
     }
 }
 
-const ColorScheme* ColorSchemeManager::findColorScheme(const QString& name)
+const ColorScheme *ColorSchemeManager::findColorScheme(const QString &name)
 {
-    if (name.isEmpty())
+    if (name.isEmpty()) {
         return defaultColorScheme();
+    }
 
     // A fix to prevent infinite loops if users puts / in ColorScheme name
     // Konsole will create a sub-folder in that case (bko 315086)
     // More code will have to go in to prevent the users from doing that.
     if (name.contains(QLatin1String("/"))) {
-        qWarning() << name << " has an invalid character / in the name ... skipping";
+        qCDebug(KonsoleDebug)<<name<<" has an invalid character / in the name ... skipping";
         return defaultColorScheme();
     }
 
@@ -189,13 +214,13 @@ const ColorScheme* ColorSchemeManager::findColorScheme(const QString& name)
             return findColorScheme(name);
         }
 
-        qWarning() << "Could not find color scheme - " << name;
+        qCDebug(KonsoleDebug) << "Could not find color scheme - " << name;
 
-        return 0;
+        return nullptr;
     }
 }
 
-QString ColorSchemeManager::findColorSchemePath(const QString& name) const
+QString ColorSchemeManager::findColorSchemePath(const QString &name) const
 {
     QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".colorscheme"));
 
@@ -206,3 +231,29 @@ QString ColorSchemeManager::findColorSchemePath(const QString& name) const
     return QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".schema"));
 }
 
+bool ColorSchemeManager::pathIsColorScheme(const QString &path)
+{
+    return path.endsWith(QLatin1String(".colorscheme"));
+}
+
+bool ColorSchemeManager::isColorSchemeDeletable(const QString &name)
+{
+    const QString path = findColorSchemePath(name);
+
+    QFileInfo fileInfo(path);
+    QFileInfo dirInfo = fileInfo.path();
+
+    return dirInfo.isWritable();
+}
+
+bool ColorSchemeManager::canResetColorScheme(const QString &name)
+{
+    const QStringList paths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".colorscheme"));
+
+    // if the colorscheme exists in both a writable location under the
+    // user's home dir and a system-wide location, then it's possible
+    // to delete the colorscheme under the user's home dir so that the
+    // colorscheme from the system-wide location can be used instead,
+    // i.e. resetting the colorscheme
+    return (paths.count() > 1);
+}
