@@ -22,20 +22,20 @@
 // Own
 #include "KeyboardTranslatorManager.h"
 
-// Qt
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QDir>
+#include "konsoledebug.h"
 
-// KDE
-#include <QDebug>
+// Qt
+#include <QFile>
+#include <QFileInfo>
+#include <QDir>
 #include <QStandardPaths>
 
 using namespace Konsole;
 
-KeyboardTranslatorManager::KeyboardTranslatorManager()
-    : _haveLoadedAll(false)
-    , _fallbackTranslator(0)
+KeyboardTranslatorManager::KeyboardTranslatorManager() :
+    _haveLoadedAll(false),
+    _fallbackTranslator(nullptr),
+    _translators(QHash<QString, KeyboardTranslator *>())
 {
     _fallbackTranslator = new FallbackKeyboardTranslator();
 }
@@ -52,16 +52,17 @@ KeyboardTranslatorManager* KeyboardTranslatorManager::instance()
     return theKeyboardTranslatorManager;
 }
 
-void KeyboardTranslatorManager::addTranslator(KeyboardTranslator* translator)
+void KeyboardTranslatorManager::addTranslator(KeyboardTranslator *translator)
 {
     _translators.insert(translator->name(), translator);
 
-    if (!saveTranslator(translator))
-        qWarning() << "Unable to save translator" << translator->name()
-                   << "to disk.";
+    if (!saveTranslator(translator)) {
+        qCDebug(KonsoleDebug) << "Unable to save translator" << translator->name()
+                              << "to disk.";
+    }
 }
 
-bool KeyboardTranslatorManager::deleteTranslator(const QString& name)
+bool KeyboardTranslatorManager::deleteTranslator(const QString &name)
 {
     Q_ASSERT(_translators.contains(name));
 
@@ -71,64 +72,69 @@ bool KeyboardTranslatorManager::deleteTranslator(const QString& name)
         _translators.remove(name);
         return true;
     } else {
-        qWarning() << "Failed to remove translator - " << path;
+        qCDebug(KonsoleDebug) << "Failed to remove translator - " << path;
         return false;
     }
 }
 
-QString KeyboardTranslatorManager::findTranslatorPath(const QString& name)
+QString KeyboardTranslatorManager::findTranslatorPath(const QString &name)
 {
     return QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".keytab"));
 }
 
 void KeyboardTranslatorManager::findTranslators()
 {
-
     QStringList list;
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konsole"), QStandardPaths::LocateDirectory);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konsole"),
+                                                       QStandardPaths::LocateDirectory);
     list.reserve(dirs.size());
 
-    Q_FOREACH (const QString& dir, dirs) {
+    Q_FOREACH (const QString &dir, dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.keytab"));
-        Q_FOREACH (const QString& file, fileNames) {
-            list.append(dir + '/' + file);
+        Q_FOREACH (const QString &file, fileNames) {
+            list.append(dir + QLatin1Char('/') + file);
         }
     }
 
     // add the name of each translator to the list and associated
     // the name with a null pointer to indicate that the translator
     // has not yet been loaded from disk
-    foreach(const QString& translatorPath, list) {
-        QString name = QFileInfo(translatorPath).baseName();
+    foreach (const QString &translatorPath, list) {
+        QString name = QFileInfo(translatorPath).completeBaseName();
 
-        if (!_translators.contains(name))
-            _translators.insert(name, 0);
+        if (!_translators.contains(name)) {
+            _translators.insert(name, nullptr);
+        }
     }
 
     _haveLoadedAll = true;
 }
 
-const KeyboardTranslator* KeyboardTranslatorManager::findTranslator(const QString& name)
+const KeyboardTranslator *KeyboardTranslatorManager::findTranslator(const QString &name)
 {
-    if (name.isEmpty())
+    if (name.isEmpty()) {
         return defaultTranslator();
+    }
 
-    if (_translators.contains(name) && _translators[name] != 0)
+    if (_translators.contains(name) && _translators[name] != nullptr) {
         return _translators[name];
+    }
 
-    KeyboardTranslator* translator = loadTranslator(name);
+    KeyboardTranslator *translator = loadTranslator(name);
 
-    if (translator != 0)
+    if (translator != nullptr) {
         _translators[name] = translator;
-    else if (!name.isEmpty())
-        qWarning() << "Unable to load translator" << name;
+    } else if (!name.isEmpty()) {
+        qCDebug(KonsoleDebug) << "Unable to load translator" << name;
+    }
 
     return translator;
 }
 
-bool KeyboardTranslatorManager::saveTranslator(const KeyboardTranslator* translator)
+bool KeyboardTranslatorManager::saveTranslator(const KeyboardTranslator *translator)
 {
-    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/konsole/");
+    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
+                        + QStringLiteral("/konsole/");
     QDir().mkpath(dir);
     const QString path = dir + translator->name() + QStringLiteral(".keytab");
 
@@ -136,8 +142,8 @@ bool KeyboardTranslatorManager::saveTranslator(const KeyboardTranslator* transla
 
     QFile destination(path);
     if (!destination.open(QIODevice::WriteOnly | QIODevice::Text)) {
-        qWarning() << "Unable to save keyboard translation:"
-                   << destination.errorString();
+        qCDebug(KonsoleDebug) << "Unable to save keyboard translation:"
+                              << destination.errorString();
         return false;
     }
 
@@ -145,7 +151,7 @@ bool KeyboardTranslatorManager::saveTranslator(const KeyboardTranslator* transla
         KeyboardTranslatorWriter writer(&destination);
         writer.writeHeader(translator->description());
 
-        foreach(const KeyboardTranslator::Entry& entry, translator->entries()) {
+        foreach (const KeyboardTranslator::Entry &entry, translator->entries()) {
             writer.writeEntry(entry);
         }
     }
@@ -155,24 +161,27 @@ bool KeyboardTranslatorManager::saveTranslator(const KeyboardTranslator* transla
     return true;
 }
 
-KeyboardTranslator* KeyboardTranslatorManager::loadTranslator(const QString& name)
+KeyboardTranslator *KeyboardTranslatorManager::loadTranslator(const QString &name)
 {
-    const QString& path = findTranslatorPath(name);
+    const QString &path = findTranslatorPath(name);
 
     QFile source(path);
-    if (name.isEmpty() || !source.open(QIODevice::ReadOnly | QIODevice::Text))
-        return 0;
+    if (name.isEmpty() || !source.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        return nullptr;
+    }
 
     return loadTranslator(&source, name);
 }
 
-KeyboardTranslator* KeyboardTranslatorManager::loadTranslator(QIODevice* source, const QString& name)
+KeyboardTranslator *KeyboardTranslatorManager::loadTranslator(QIODevice *source,
+                                                              const QString &name)
 {
-    KeyboardTranslator* translator = new KeyboardTranslator(name);
+    auto translator = new KeyboardTranslator(name);
     KeyboardTranslatorReader reader(source);
     translator->setDescription(reader.description());
-    while (reader.hasNextEntry())
+    while (reader.hasNextEntry()) {
         translator->addEntry(reader.nextEntry());
+    }
 
     source->close();
 
@@ -180,16 +189,16 @@ KeyboardTranslator* KeyboardTranslatorManager::loadTranslator(QIODevice* source,
         return translator;
     } else {
         delete translator;
-        return 0;
+        return nullptr;
     }
 }
 
-const KeyboardTranslator* KeyboardTranslatorManager::defaultTranslator()
+const KeyboardTranslator *KeyboardTranslatorManager::defaultTranslator()
 {
     // Try to find the default.keytab file if it exists, otherwise
     // fall back to the internal hard-coded fallback translator
-    const KeyboardTranslator* translator = findTranslator(QStringLiteral("default"));
-    if (!translator) {
+    const KeyboardTranslator *translator = findTranslator(QStringLiteral("default"));
+    if (translator == nullptr) {
         translator = _fallbackTranslator;
     }
     return translator;
