@@ -71,6 +71,8 @@ static void sortByNameProfileList(QList<Profile::Ptr>& list)
 ProfileManager::ProfileManager()
     : _profiles(QSet<Profile::Ptr>())
     , _favorites(QSet<Profile::Ptr>())
+    , _defaultProfile(nullptr)
+    , _fallbackProfile(nullptr)
     , _loadedAllProfiles(false)
     , _loadedFavorites(false)
     , _shortcuts(QMap<QKeySequence, ShortcutData>())
@@ -102,8 +104,9 @@ ProfileManager::ProfileManager()
 
         if (!path.isEmpty()) {
             Profile::Ptr profile = loadProfile(path);
-            if (profile)
+            if (profile) {
                 _defaultProfile = profile;
+            }
         }
     }
 
@@ -127,25 +130,30 @@ ProfileManager* ProfileManager::instance()
 Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
 {
     // the fallback profile has a 'special' path name, "FALLBACK/"
-    if (shortPath == _fallbackProfile->path())
+    if (shortPath == _fallbackProfile->path()) {
         return _fallbackProfile;
+    }
 
     QString path = shortPath;
 
     // add a suggested suffix and relative prefix if missing
     QFileInfo fileInfo(path);
 
-    if (fileInfo.isDir())
+    if (fileInfo.isDir()) {
         return Profile::Ptr();
+    }
 
-    if (fileInfo.suffix() != QLatin1String("profile"))
+    if (fileInfo.suffix() != QLatin1String("profile")) {
         path.append(QLatin1String(".profile"));
-    if (fileInfo.path().isEmpty() || fileInfo.path() == QLatin1String("."))
+    }
+    if (fileInfo.path().isEmpty() || fileInfo.path() == QLatin1String(".")) {
         path.prepend(QLatin1String("konsole") + QDir::separator());
+    }
 
     // if the file is not an absolute path, look it up
-    if (!fileInfo.isAbsolute())
+    if (!fileInfo.isAbsolute()) {
         path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, path);
+    }
 
     // if the file is not found, return immediately
     if (path.isEmpty()) {
@@ -154,8 +162,9 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
 
     // check that we have not already loaded this profile
     foreach(const Profile::Ptr& profile, _profiles) {
-        if (profile->path() == path)
+        if (profile->path() == path) {
             return profile;
+        }
     }
 
     // guard to prevent problems if a profile specifies itself as its parent
@@ -172,7 +181,7 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
     }
 
     // load the profile
-    ProfileReader* reader = new KDE4ProfileReader;
+    auto reader = new ProfileReader();
 
     Profile::Ptr newProfile = Profile::Ptr(new Profile(fallbackProfile()));
     newProfile->setProperty(Profile::Path, path);
@@ -190,6 +199,9 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
     if (!result) {
         qCDebug(KonsoleDebug) << "Could not load profile from " << path;
         return Profile::Ptr();
+    } else if (newProfile->name().isEmpty()) {
+        qCWarning(KonsoleDebug) << path << " does not have a valid name, ignoring.";
+        return Profile::Ptr();
     } else {
         addProfile(newProfile);
         return newProfile;
@@ -197,13 +209,14 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
 }
 QStringList ProfileManager::availableProfilePaths() const
 {
-    KDE4ProfileReader kde4Reader;
+    auto reader = new ProfileReader();
 
     QStringList paths;
-    paths += kde4Reader.findProfiles();
+    paths += reader->findProfiles();
 
     qStableSort(paths.begin(), paths.end(), stringLessThan);
 
+    delete reader;
     return paths;
 }
 
@@ -224,8 +237,9 @@ QStringList ProfileManager::availableProfileNames() const
 
 void ProfileManager::loadAllProfiles()
 {
-    if (_loadedAllProfiles)
+    if (_loadedAllProfiles) {
         return;
+    }
 
     const QStringList& paths = availableProfilePaths();
     foreach(const QString& path, paths) {
@@ -242,13 +256,15 @@ void ProfileManager::sortProfiles(QList<Profile::Ptr>& list)
 
     for (const auto & i : list) {
         // dis-regard the fallback profile
-        if (i->path() == _fallbackProfile->path())
+        if (i->path() == _fallbackProfile->path()) {
             continue;
+        }
 
-        if (i->menuIndexAsInt() == 0)
+        if (i->menuIndexAsInt() == 0) {
             lackingIndices.append(i);
-        else
+        } else {
             havingIndices.append(i);
+        }
     }
 
     // sort by index
@@ -324,12 +340,12 @@ Profile::Ptr ProfileManager::fallbackProfile() const
 
 QString ProfileManager::saveProfile(Profile::Ptr profile)
 {
-    ProfileWriter* writer = new KDE4ProfileWriter;
+    auto writer = new ProfileWriter();
 
     QString newPath = writer->getPath(profile);
 
     if (!writer->writeProfile(newPath, profile)) {
-        KMessageBox::sorry(0,
+        KMessageBox::sorry(nullptr,
                            i18n("Konsole does not have permission to save this profile to %1", newPath));
     }
     delete writer;
@@ -342,6 +358,8 @@ void ProfileManager::changeProfile(Profile::Ptr profile,
 {
     Q_ASSERT(profile);
 
+    const QString origPath = profile->path();
+
     // never save a profile with empty name into disk!
     persistent = persistent && !profile->name().isEmpty();
 
@@ -411,6 +429,27 @@ void ProfileManager::changeProfile(Profile::Ptr profile,
     // it has no file on disk
     if (persistent && !newProfile->isHidden()) {
         newProfile->setProperty(Profile::Path, saveProfile(newProfile));
+        // if the profile was renamed, after saving the new profile
+        // delete the old/redundant profile.
+        // only do this if origPath is not empty, because it's empty
+        // when creating a new profile, this works around a bug where
+        // the newly created profile appears twice in the ProfileSettings
+        // dialog
+        if (!origPath.isEmpty() && (newProfile->path() != origPath)) {
+            // this is needed to include the old profile too
+            _loadedAllProfiles = false;
+           const QList<Profile::Ptr> availableProfiles = ProfileManager::instance()->allProfiles();
+            foreach(auto oldProfile, availableProfiles) {
+                if (oldProfile->path() == origPath) {
+                    // assign the same shortcut of the old profile to
+                    // the newly renamed profile
+                    const auto oldShortcut = shortcut(oldProfile);
+                    if (deleteProfile(oldProfile)) {
+                        setShortcut(newProfile, oldShortcut);
+                    }
+                }
+            }
+        }
     }
 
     // notify the world about the change
@@ -419,8 +458,9 @@ void ProfileManager::changeProfile(Profile::Ptr profile,
 
 void ProfileManager::addProfile(Profile::Ptr profile)
 {
-    if (_profiles.isEmpty())
+    if (_profiles.isEmpty()) {
         _defaultProfile = profile;
+    }
 
     _profiles.insert(profile);
 
@@ -474,15 +514,19 @@ void ProfileManager::setDefaultProfile(Profile::Ptr profile)
 void ProfileManager::saveDefaultProfile()
 {
     QString path = _defaultProfile->path();
+    auto writer = new ProfileWriter();
 
-    if (path.isEmpty())
-        path = KDE4ProfileWriter().getPath(_defaultProfile);
+    if (path.isEmpty()) {
+        path = writer->getPath(_defaultProfile);
+    }
 
     QFileInfo fileInfo(path);
 
     KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     KConfigGroup group = appConfig->group("Desktop Entry");
     group.writeEntry("DefaultProfile", fileInfo.fileName());
+
+    delete writer;
 }
 
 QSet<Profile::Ptr> ProfileManager::findFavorites()
@@ -493,8 +537,9 @@ QSet<Profile::Ptr> ProfileManager::findFavorites()
 }
 void ProfileManager::setFavorite(Profile::Ptr profile , bool favorite)
 {
-    if (!_profiles.contains(profile))
+    if (!_profiles.contains(profile)) {
         addProfile(profile);
+    }
 
     if (favorite && !_favorites.contains(profile)) {
         _favorites.insert(profile);
@@ -569,8 +614,9 @@ void ProfileManager::setShortcut(Profile::Ptr profile ,
     QKeySequence existingShortcut = shortcut(profile);
     _shortcuts.remove(existingShortcut);
 
-    if (keySequence.isEmpty())
+    if (keySequence.isEmpty()) {
         return;
+    }
 
     ShortcutData data;
     data.profileKey = profile;
@@ -583,8 +629,9 @@ void ProfileManager::setShortcut(Profile::Ptr profile ,
 }
 void ProfileManager::loadFavorites()
 {
-    if (_loadedFavorites)
+    if (_loadedFavorites) {
         return;
+    }
 
     KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     KConfigGroup favoriteGroup = appConfig->group("Favorite Profiles");
@@ -607,8 +654,9 @@ void ProfileManager::loadFavorites()
     // load any remaining favorites
     foreach(const QString& favorite, favoriteSet) {
         Profile::Ptr profile = loadProfile(favorite);
-        if (profile)
+        if (profile) {
             _favorites.insert(profile);
+        }
     }
 
     _loadedFavorites = true;
@@ -673,8 +721,9 @@ QKeySequence ProfileManager::shortcut(Profile::Ptr profile) const
     while (iter.hasNext()) {
         iter.next();
         if (iter.value().profileKey == profile
-                || iter.value().profilePath == profile->path())
+                || iter.value().profilePath == profile->path()) {
             return iter.key();
+        }
     }
 
     return QKeySequence();
