@@ -88,7 +88,7 @@ void PartTest::testFd()
     auto layout = new QVBoxLayout(dialog.data());
     layout->addWidget(new QLabel(QStringLiteral("Output of 'ping localhost' should appear in a terminal below for 5 seconds")));
     layout->addWidget(terminalPart->widget());
-    QTimer::singleShot(5000, dialog.data(), SLOT(close()));
+    QTimer::singleShot(5000, dialog.data(), &QDialog::close);
     dialog.data()->exec();
 
     delete terminalPart;
