@@ -192,7 +192,7 @@ void ProfileTest::testProfileFileNames()
 {
     Profile::Ptr profile = Profile::Ptr(new Profile);
     QFileInfo fileInfo;
-    ProfileWriter *writer = new KDE4ProfileWriter;
+    auto writer = new ProfileWriter();
 
     profile->setProperty(Profile::UntranslatedName, QStringLiteral("Indiana"));
     fileInfo.setFile(writer->getPath(profile));
