@@ -55,6 +55,9 @@ ProfileSettings::ProfileSettings(QWidget* aParent)
     sessionTable->setItemDelegateForColumn(ShortcutColumn, new ShortcutItemDelegate(this));
     sessionTable->setEditTriggers(sessionTable->editTriggers() | QAbstractItemView::SelectedClicked);
 
+    // double clicking the profile name opens the profile edit dialog
+    connect(sessionTable, &QTableView::doubleClicked, this, &Konsole::ProfileSettings::doubleClicked);
+
     // populate the table with profiles
     populateTable();
 
@@ -90,18 +93,6 @@ void ProfileSettings::itemDataChanged(QStandardItem* item)
         QKeySequence sequence = QKeySequence::fromString(item->text());
         ProfileManager::instance()->setShortcut(item->data(ShortcutRole).value<Profile::Ptr>(),
                                                 sequence);
-    } else if (item->column() == ProfileNameColumn) {
-        QString newName = item->text();
-        Profile::Ptr profile = item->data(ProfileKeyRole).value<Profile::Ptr>();
-        QString oldName = profile->name();
-
-        if (newName != oldName) {
-            QHash<Profile::Property, QVariant> properties;
-            properties.insert(Profile::Name, newName);
-            properties.insert(Profile::UntranslatedName, newName);
-
-            ProfileManager::instance()->changeProfile(profile, properties);
-        }
     }
 }
 
@@ -119,16 +110,18 @@ int ProfileSettings::rowForProfile(const Profile::Ptr profile) const
 void ProfileSettings::removeItems(const Profile::Ptr profile)
 {
     int row = rowForProfile(profile);
-    if (row < 0)
+    if (row < 0) {
         return;
+    }
 
     _sessionModel->removeRow(row);
 }
 void ProfileSettings::updateItems(const Profile::Ptr profile)
 {
     const int row = rowForProfile(profile);
-    if (row < 0)
+    if (row < 0) {
         return;
+    }
 
     QList<QStandardItem*> items;
     items << _sessionModel->item(row, ProfileNameColumn);
@@ -141,17 +134,21 @@ void ProfileSettings::updateItemsForProfile(const Profile::Ptr profile, QList<QS
 {
     // Profile Name
     items[ProfileNameColumn]->setText(profile->name());
-    if (!profile->icon().isEmpty())
+    if (!profile->icon().isEmpty()) {
         items[ProfileNameColumn]->setIcon(QIcon::fromTheme(profile->icon()));
+    }
     items[ProfileNameColumn]->setData(QVariant::fromValue(profile), ProfileKeyRole);
-    items[ProfileNameColumn]->setToolTip(i18nc("@info:tooltip", "Click to rename profile"));
+    // only allow renaming the profile from the edit profile dialog
+    // so as to use ProfileManager::checkProfileName()
+    items[ProfileNameColumn]->setEditable(false);
 
     // Favorite Status
     const bool isFavorite = ProfileManager::instance()->findFavorites().contains(profile);
-    if (isFavorite)
+    if (isFavorite) {
         items[FavoriteStatusColumn]->setData(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")), Qt::DecorationRole);
-    else
+    } else {
         items[FavoriteStatusColumn]->setData(QIcon(), Qt::DecorationRole);
+    }
     items[FavoriteStatusColumn]->setData(QVariant::fromValue(profile), ProfileKeyRole);
     items[FavoriteStatusColumn]->setToolTip(i18nc("@info:tooltip", "Click to toggle status"));
 
@@ -161,15 +158,26 @@ void ProfileSettings::updateItemsForProfile(const Profile::Ptr profile, QList<QS
     items[ShortcutColumn]->setData(QVariant::fromValue(profile), ShortcutRole);
     items[ShortcutColumn]->setToolTip(i18nc("@info:tooltip", "Double click to change shortcut"));
 }
+
+void ProfileSettings::doubleClicked(const QModelIndex &index)
+{
+    QStandardItem *item = _sessionModel->itemFromIndex(index);
+    if (item->column() == ProfileNameColumn) {
+        editSelected();
+    }
+}
+
 void ProfileSettings::addItems(const Profile::Ptr profile)
 {
-    if (profile->isHidden())
+    if (profile->isHidden()) {
         return;
+    }
 
     QList<QStandardItem*> items;
     items.reserve(3);
-    for (int i = 0; i < 3; i++)
+    for (int i = 0; i < 3; i++) {
         items.append(new QStandardItem);
+    }
 
     updateItemsForProfile(profile, items);
     _sessionModel->appendRow(items);
@@ -246,8 +254,9 @@ void ProfileSettings::tableSelectionChanged(const QItemSelection&)
 void ProfileSettings::deleteSelected()
 {
     foreach(const Profile::Ptr & profile, selectedProfiles()) {
-        if (profile != ProfileManager::instance()->defaultProfile())
+        if (profile != ProfileManager::instance()->defaultProfile()) {
             ProfileManager::instance()->deleteProfile(profile);
+        }
     }
 }
 void ProfileSettings::setSelectedAsDefault()
@@ -288,10 +297,11 @@ void ProfileSettings::createProfile()
     Profile::Ptr sourceProfile;
 
     Profile::Ptr selectedProfile = currentProfile();
-    if (!selectedProfile)
+    if (!selectedProfile) {
         sourceProfile = ProfileManager::instance()->defaultProfile();
-    else
+    } else {
         sourceProfile = selectedProfile;
+    }
 
     Q_ASSERT(sourceProfile);
 
@@ -346,12 +356,14 @@ QList<Profile::Ptr> ProfileSettings::selectedProfiles() const
 {
     QList<Profile::Ptr> list;
     QItemSelectionModel* selection = sessionTable->selectionModel();
-    if (selection == nullptr)
+    if (selection == nullptr) {
         return list;
+    }
 
     foreach(const QModelIndex & index, selection->selectedIndexes()) {
-        if (index.column() == ProfileNameColumn)
+        if (index.column() == ProfileNameColumn) {
             list << index.data(ProfileKeyRole).value<Profile::Ptr>();
+        }
     }
 
     return list;
@@ -360,8 +372,9 @@ Profile::Ptr ProfileSettings::currentProfile() const
 {
     QItemSelectionModel* selection = sessionTable->selectionModel();
 
-    if ((selection == nullptr) || selection->selectedRows().count() != 1)
+    if ((selection == nullptr) || selection->selectedRows().count() != 1) {
         return Profile::Ptr();
+    }
 
     return  selection->
             selectedIndexes().first().data(ProfileKeyRole).value<Profile::Ptr>();
@@ -447,7 +460,9 @@ bool FavoriteItemDelegate::editorEvent(QEvent* aEvent, QAbstractItemModel*,
     return true;
 }
 ShortcutItemDelegate::ShortcutItemDelegate(QObject* aParent)
-    : QStyledItemDelegate(aParent)
+    : QStyledItemDelegate(aParent),
+    _modifiedEditors(QSet<QWidget *>()),
+    _itemsBeingEdited(QSet<QModelIndex>())
 {
 }
 void ShortcutItemDelegate::editorModified(const QKeySequence& keys)
@@ -465,8 +480,9 @@ void ShortcutItemDelegate::setModelData(QWidget* editor, QAbstractItemModel* mod
 {
     _itemsBeingEdited.remove(index);
 
-    if (!_modifiedEditors.contains(editor))
+    if (!_modifiedEditors.contains(editor)) {
         return;
+    }
 
     QString shortcut = qobject_cast<KKeySequenceWidget*>(editor)->keySequence().toString();
     model->setData(index, shortcut, Qt::DisplayRole);
@@ -490,9 +506,10 @@ QWidget* ShortcutItemDelegate::createEditor(QWidget* aParent, const QStyleOption
 void ShortcutItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option,
                                  const QModelIndex& index) const
 {
-    if (_itemsBeingEdited.contains(index))
+    if (_itemsBeingEdited.contains(index)) {
         StyledBackgroundPainter::drawBackground(painter, option, index);
-    else
+    } else {
         QStyledItemDelegate::paint(painter, option, index);
+    }
 }
 
